@@ -4,21 +4,12 @@ use strict;
 use warnings;
 use base qw(Firefox::Marionette::Exception::Response);
 
-our $VERSION = '1.45';
+our $VERSION = '1.46';
 
 sub throw {
     my ( $class, $response, $parameters ) = @_;
-    my $string;
-    if ( defined $parameters ) {
-        $string =
-            'Failed to find '
-          . $parameters->{using} . ' of "'
-          . $parameters->{value};
-    }
-    else {
-        $string = $response->{error}->{message};
-    }
-    my $self = bless {
+    my $string = $response->{error}->{message};
+    my $self   = bless {
         string     => $string,
         response   => $response,
         parameters => $parameters,
@@ -35,7 +26,7 @@ Firefox::Marionette::Exception::StaleElement - Represents a 'stale element refer
 
 =head1 VERSION
 
-Version 1.45
+Version 1.46
 
 =head1 SYNOPSIS
 
