@@ -3,7 +3,7 @@ package Firefox::Marionette::WebAuthn::Authenticator;
 use strict;
 use warnings;
 
-our $VERSION = '1.43';
+our $VERSION = '1.46';
 
 sub BLE        { return 'ble' }
 sub CTAP1_U2F  { return 'ctap1/u2f' }
@@ -65,7 +65,7 @@ Firefox::Marionette::WebAuthn::Authenticator - Represents a Firefox WebAuthn Aut
 
 =head1 VERSION
 
-Version 1.43
+Version 1.46
 
 =head1 SYNOPSIS
 
@@ -90,7 +90,7 @@ This module handles the implementation of a L<Virtual Authenticator|https://www.
 
 =head2 BLE
 
-return 'ble', the L<transport|/transport> code for a L<Bluetooth Low Energy|https://en.wikipedia.org/wiki/Bluetooth_Low_Energy>.
+return 'ble', the L<transport|/transport> code for a L<Bluetooth Low Energy|https://en.wikipedia.org/wiki/Bluetooth_Low_Energy> transport.
 
 =head2 CTAP1_U2F
 
